@@ -2,7 +2,7 @@ context("dodsReplace")
 
 
 test_that("prism is replaced", {
-  expect_equal(geoknife:::dodsReplace('http://cida.usgs.gov/thredds/dodsC/prism_v2'),'dods://cida.usgs.gov/thredds/dodsC/prism_v2')
+  expect_equal(geoknife:::dodsReplace('https://cida.usgs.gov/thredds/dodsC/prism_v2'),'dods://cida.usgs.gov/thredds/dodsC/prism_v2')
 })
 
 test_that("nldas is replaced", {
